@@ -12,11 +12,11 @@ use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.26_03';
+	$VERSION = '1.27_01';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
-use constant UNBOUND_VERSION => scalar eval {
+use constant UB_VERSION => scalar eval {
 	my $version = Net::DNS::Resolver::libunbound->VERSION();
 	my ( $major, $minor, $minimus ) = split /\D/, $version;
 	( $major * 100 + $minor ) * 100 + $minimus;
@@ -24,10 +24,11 @@ use constant UNBOUND_VERSION => scalar eval {
 
 use constant UB_CONTEXT => 'Net::DNS::Resolver::Unbound::Context';
 
-use constant IP_PREF	 => UNBOUND_VERSION > 11100;
-use constant SET_TLS	 => UB_CONTEXT->can('set_tls');
-use constant SET_STUB	 => UB_CONTEXT->can('set_stub');
+use constant IP_PREF	 => UB_VERSION > 11100;
+use constant ASYNC	 => UB_CONTEXT->can('async');
 use constant ADD_TA_AUTR => UB_CONTEXT->can('add_ta_autr');
+use constant SET_STUB	 => UB_CONTEXT->can('set_stub');
+use constant SET_TLS	 => UB_CONTEXT->can('set_tls');
 
 
 =head1 NAME
@@ -73,7 +74,7 @@ extracted from the presented packet.
 =item *
 
 Result packet is synthesised in libunbound and not the "real thing".
-In particular, the returned queryID is always zero.
+In particular, the queryID returned by Unbound is always zero.
 
 =back
 
@@ -114,19 +115,25 @@ sub new {
 =head2 nameservers
 
     my $stub_resolver = Net::DNS::Resolver::Unbound->new(
-	nameservers => [ '127.0.0.53' ]
+	nameserver => '127.0.0.53'
 	);
 
     my $fully_recursive = Net::DNS::Resolver::Unbound->new(
-	nameservers => []		# override /etc/resolv.conf
-	);
-
-    my $dnssec_resolver = Net::DNS::Resolver::Unbound->new(
-	nameservers => [],
+	nameservers => [],		# override /etc/resolv.conf
 	add_ta_file => '/var/lib/unbound/root.key'
 	);
 
-    $stub_resolver->nameservers( '127.0.0.53', ... );
+    my $DoT_resolver = Net::DNS::Resolver->new(
+	nameserver => '2606:4700:4700::1111@853#cloudflare-dns.com',
+	nameserver => '2001:4860:4860::8888@853#dns.google',
+	nameserver => '8.8.8.8@853#dns.google',
+	nameserver => '9.9.9.9@853#dns.quad9.net',
+	option     => [qw(tls-cert-bundle /etc/ssl/cert.pem)],
+	set_tls    => 1
+	);
+
+    $resolver->nameservers( '::1', '127.0.0.1', ... );
+    @nameservers = $resolver->nameservers;
 
 By default, DNS queries are sent to the IP addresses listed in
 /etc/resolv.conf or similar platform-specific sources.
@@ -427,7 +434,7 @@ If false (by default), a process is forked to perform the work.
 
 sub async_thread {
 	my ( $self, $threaded ) = @_;
-	return $self->_config( 'async', $threaded );
+	return ASYNC ? $self->_config( 'async', $threaded ) : undef;
 }
 
 
